@@ -1,12 +1,10 @@
 package SVK::Command::Diff;
 use strict;
-our $VERSION = $SVK::VERSION;
+use SVK::Version;  our $VERSION = $SVK::VERSION;
 
 use base qw( SVK::Command );
-use SVK::XD;
 use SVK::I18N;
-use SVK::Util qw(get_anchor);
-use SVK::Editor::Diff;
+use autouse 'SVK::Util' => qw(get_anchor);
 
 sub options {
     ("v|verbose"    => 'verbose',
@@ -78,15 +76,15 @@ sub run {
 	SVK::Editor::Status->new
 	: SVK::Editor::Diff->new
 	( cb_basecontent =>
-	  sub { my ($rpath) = @_;
-		my $base = $oldroot->file_contents ("$target->{path}/$rpath");
+	  sub { my ($rpath, $pool) = @_;
+		my $base = $oldroot->file_contents ("$target->{path}/$rpath", $pool);
 		return $base;
 	    },
 	  cb_baseprop =>
-	  sub { my ($rpath, $pname) = @_;
+	  sub { my ($rpath, $pname, $pool) = @_;
 		my $path = "$target->{path}/$rpath";
-		return $oldroot->check_path ($path) == $SVN::Node::none ?
-		    undef : $oldroot->node_prop ($path, $pname);
+		return $oldroot->check_path ($path, $pool) == $SVN::Node::none ?
+		    undef : $oldroot->node_prop ($path, $pname, $pool);
 	    },
 	  $cb_llabel ? (cb_llabel => $cb_llabel) : (llabel => "revision $r1"),
 	  rlabel => $target2->{copath} ? 'local' : "revision $r2",
