@@ -1,10 +1,13 @@
 package SVK::Editor::Combine;
 use strict;
-use SVN::Simple::Edit;
 
-our $VERSION = $SVK::VERSION;
+use SVK::Version;  our $VERSION = $SVK::VERSION;
+
+require SVN::Delta;
 our @ISA = qw(SVN::Delta::Editor);
 
+use autouse 'SVK::Util' => qw( tmpfile );
+
 =head1 NAME
 
 SVK::Editor::Combine - An editor combining several editor calls to one
@@ -22,8 +25,6 @@ SVK::Editor::Combine - An editor combining several editor calls to one
 
 =cut
 
-use SVK::Util qw( tmpfile );
-
 sub replay {
     my ($self, $editor, $base_rev) = @_;
 	my $edit = SVN::Simple::Edit->new
