@@ -1,8 +1,7 @@
 package SVK::Editor::Status;
 use strict;
 use SVN::Delta;
-use SVK::Notify;
-our $VERSION = $SVK::VERSION;
+use SVK::Version;  our $VERSION = $SVK::VERSION;
 our @ISA = qw(SVN::Delta::Editor);
 
 sub new {
